@@ -98,6 +98,7 @@ setMethod(
   "distribution",
   signature(samc = "samc", init = "missing", origin = "missing", dest = "missing", time = "numeric"),
   function(samc, time) {
+    .disable_conv(samc)
 
     if (!samc@override)
       stop("This version of the distribution() method produces a large dense matrix.\nSee the documentation for details.", call. = FALSE)
@@ -122,8 +123,14 @@ setMethod(
   "distribution",
   signature(samc = "samc", init = "missing", origin = "location", dest = "missing", time = "numeric"),
   function(samc, origin, time) {
-    if (length(origin) != 1)
-      stop("origin can only contain a single location for this version of the function", call. = FALSE)
+    .disable_conv(samc)
+
+    if (is(origin, "matrix")) {
+      if (nrow(origin) > 1) stop("Only a single origin is supported for CRW", call. = FALSE)
+    } else {
+      if (length(origin) != 1)
+        stop("origin can only contain a single value for this version of the function", call. = FALSE)
+    }
 
     origin <- .process_locations(samc, origin)
 
@@ -148,6 +155,9 @@ setMethod(
   "distribution",
   signature(samc = "samc", init = "missing", origin = "missing", dest = "location", time = "numeric"),
   function(samc, dest, time) {
+    .disable_conv(samc)
+    .disable_crw(samc)
+
     if (length(dest) != 1)
       stop("dest can only contain a single location for this version of the function", call. = FALSE)
 
@@ -174,6 +184,9 @@ setMethod(
   "distribution",
   signature(samc = "samc", init = "missing", origin = "location", dest = "location", time = "numeric"),
   function(samc, origin, dest, time) {
+    .disable_conv(samc)
+    .disable_crw(samc)
+
     if (length(dest) != 1)
       stop("dest can only contain a single location for this version of the function", call. = FALSE)
 
@@ -197,22 +210,33 @@ setMethod(
   signature(samc = "samc", init = "ANY", origin = "missing", dest = "missing", time = "numeric"),
   function(samc, init, time) {
     check(samc, init)
+    .disable_crw(samc)
 
     pv <- .process_init(samc, init)
 
     .validate_time_steps(time)
 
-    q <- samc$q_matrix
+    if (samc@solver %in% c("direct", "iter")) {
+      q = samc$q_matrix
 
-    time <- c(0, time)
+      time = c(0, time)
 
-    res <- .psiq(q, pv, time)
+      res = .psiq(q, pv, time)
 
-    res <- lapply(res, as.vector)
+      res = lapply(res, as.vector)
+
+      if (length(res) == 1) {
+        return(res[[1]])
+      } else {
+        return(res)
+      }
+    } else if (samc@solver == "conv") {
+      results_list <- samc:::.convolution_short(time, samc@conv_cache, pv, samc@threads)
+
+      res = as.vector(results_list$dist[[1]])
 
-    if (length(res) == 1) {
-      return(res[[1]])
-    } else {
       return(res)
+    } else {
+      stop("Invalid method attribute in samc object.")
     }
   })
